@@ -4,13 +4,14 @@ from time import time
 
 import numpy as np
 import matplotlib.pyplot as plt
-from bart import bart  # pylint: disable=E0401
 
 from pygrappa import pars
 from utils import gridder
 
+from bart import bart  # pylint: disable=E0401
 
-def sos(x0):
+
+def _sos(x0):
     return np.sqrt(np.sum(np.abs(x0)**2, axis=-1))
 
 
@@ -32,16 +33,16 @@ if __name__ == '__main__':
 
     # Take a looksie
     plt.subplot(1, 3, 1)
-    plt.imshow(sos(gridder(kx, ky, k, sx, sx)))
+    plt.imshow(_sos(gridder(kx, ky, k, sx, sx)))
     plt.title('Truth')
 
     plt.subplot(1, 3, 2)
-    plt.imshow(sos(gridder(kx, ky, ku, sx, sx)))
+    plt.imshow(_sos(gridder(kx, ky, ku, sx, sx)))
     plt.title('Undersampled')
 
     plt.subplot(1, 3, 3)
     res = pars(kx, ky, ku, sens, kernel_radius=.8)
-    plt.imshow(sos(res))
+    plt.imshow(_sos(res))
     plt.title('PARS')
 
     plt.show()
