@@ -3,7 +3,10 @@
 import numpy as np
 import matplotlib.pyplot as plt
 from phantominator import shepp_logan
-from skimage.metrics import normalized_root_mse as compare_nrmse # pylint: disable=E0611,E0401
+try:
+    from skimage.metrics import normalized_root_mse as compare_nrmse  # pylint: disable=E0611,E0401
+except ImportError:
+    from skimage.measure import compare_nrmse
 from tqdm import tqdm
 
 from pygrappa import cgrappa as grappa
